@@ -23,7 +23,12 @@ class ProvPopTableResultsWrapper():
     A result of `ProvPopTable.fix_issues()` wrapped in the object.
     '''
 
-    def __init__(self, orig_table, result_fix_issues: List):
+    def __init__(
+        self, 
+        orig_table, 
+        result_fix_issues: List,
+        method: str
+    ):
         '''
         Create an instance of `ProvPopTableResultsWrapper`.
 
@@ -33,13 +38,13 @@ class ProvPopTableResultsWrapper():
         * `result_fix_issues`: a list of `ProvPopTable` and 
             `pandas.DataFrame`; the return value of 
             `orig_table.fix_issues(return_all_mods = True)`.
+        * `method`: a str; a method used to fix the original table.
         '''
 
         self.__orig_table = orig_table
         self.__fixed_table = result_fix_issues[0]
-        self.__corrections =\
-            result_fix_issues[1:] if len(result_fix_issues) >= 2 \
-                else None
+        self.__corrections = result_fix_issues[1:]
+        self.__method = method
 
     def get_corrections(self):
         '''
@@ -69,6 +74,47 @@ class ProvPopTableResultsWrapper():
 
         return self.__fixed_table
 
+    def get_metric_all(self, include_zeros: bool = False):
+        '''
+        Get the following metrics at each correction all at once:
+            + range
+            + average sparsity
+            + average magnitude
+            + standard deviation
+
+        Usage
+        -----
+        `self.get_metric_all(include_zeros)`
+
+        Arguments
+        ---------
+        * `include_zeros`: a bool, `False` by default; if `True`, then any
+            corrections with a value 0 in the correction DataFrame will be
+            included in the computation of evaluation metric.
+        '''
+
+        join_on = self.__fixed_table.get_pop_groups()
+        join_on += ['Component']
+        summary_metrics =\
+            self.get_metric_range()\
+            .merge(
+                self.get_metric_sparsity(),
+                on = join_on,
+                how = 'inner'
+            )\
+            .merge(
+                self.get_metric_magni(include_zeros),
+                on = join_on,
+                how = 'inner'
+            )\
+            .merge(
+                self.get_metric_sd(include_zeros),
+                on = join_on,
+                how = 'inner'
+            )
+        
+        return summary_metrics
+
     def get_metric_magni(self, include_zeros: bool = False):
         '''
         Get the magnitude of changes made due to corrections in
@@ -128,7 +174,7 @@ class ProvPopTableResultsWrapper():
 
         Usage
         -----
-        `self.get_metric_num_cells(self, include_zeros)`
+        `self.get_metric_num_cells(include_zeros)`
 
         Arguments
         ---------
@@ -287,21 +333,24 @@ class ProvPopTableResultsWrapper():
 
     def plot_pop(
         self, 
+        sex,
         of: str = 'both',
         age_range: Optional[List[int]] = None,
         alpha: float = .5
     ):
         '''
         Plot the barplot of ages vs. end-of-period populations of the
-        `of` population table, where ages are filtered by `age_range`.
-        Set `alpha` for transparency.
+        `of` population table, where ages are filtered by `sex` and 
+        `age_range`. Set `alpha` for transparency.
 
         Usage
         -----
-        `self.plot_pop([of, age_range, alpha])`
+        `self.plot_pop(sex[, of, age_range, alpha])`
 
         Arguments
         ---------
+        * `sex`: an object; use only records having the same `sex` in 
+            `poptbl`.
         * `of`: a str, 'both' by default; depending on what population 
             table the user wants to use to draw a plot, either specify
             it as 'orig', 'fixed', or 'both'. Any other string will raise 
@@ -319,23 +368,27 @@ class ProvPopTableResultsWrapper():
         if of == 'orig':
             plot_pop(
                 poptbl = self.__orig_table, 
+                sex = sex,
                 age_range = age_range, 
                 alpha = alpha
             )
         elif of == 'fixed':
             plot_pop(
                 poptbl = self.__fixed_table, 
+                sex = sex,
                 age_range = age_range, 
                 alpha = alpha
             )
         elif of == 'both':
             plot_pop(
                 poptbl = self.__orig_table, 
+                sex = sex,
                 age_range = age_range, 
                 alpha = alpha
             )
             plot_pop(
                 poptbl = self.__fixed_table, 
+                sex = sex,
                 age_range = age_range, 
                 alpha = alpha
             )
@@ -345,6 +398,48 @@ class ProvPopTableResultsWrapper():
             )
         else:
             raise NotImplementedError
+        plt.title(f"End-of-period population of sex {sex}")
         plt.xlabel(pop_age)
         plt.ylabel(pop_end)
         plt.show()
+
+    def summary(self, include_zeros: bool = False):
+        '''
+        Get the following information:
+            + method used
+            + total number of cells changed
+            + number of cells changed at each affected column
+            + average magnitude of each correction
+            + range of each correction
+            + standard deviation of each correction
+            + average sparsity of each correction
+        
+        Usage
+        -----
+        `self.summary(include_zeros)`
+
+        Arguments
+        ---------
+        * `include_zeros`: a bool, `False` by default; if `True`, then any
+            corrections with a value 0 in the correction DataFrame will be
+            included in the computation of evaluation metric. 
+
+        Returns
+        -------
+        A str.
+        '''
+
+        summary = ''
+        num_cells = self.get_metric_num_cells()
+        summary +=\
+            f"Method used: {self.__method}\n" +\
+            f"Total cells changed: {sum(num_cells.values())}\n"
+        
+        for k, v in num_cells.items():
+            summary += f"    {k}: {v}\n"
+
+        summary +=\
+            "Metrics at each correction:\n" +\
+            str(self.get_metric_all(include_zeros))
+
+        return summary
