@@ -9,25 +9,24 @@ import numpy as np
 
 
 
-# Need to modify in order to handle cases where a table has more than
-# one sex. Currently, plot_pop() only correctly deals with cases where
-# there is only one type of sex in a table.
 def plot_pop(
     poptbl, 
+    sex,
     age_range: Optional[List[int]] = None, 
     alpha: float = .5
 ):
     '''
     Get the barplot of ages vs. end-of-period populations of `poptbl`
-    filtered by `age_range`. Set `alpha` for transparency.
+    filtered by `sex` and `age_range`. Set `alpha` for transparency.
 
     Usage
     -----
-    `plot_pop(poptbl[, age_range, alpha])`
+    `plot_pop(poptbl, sex[, age_range, alpha])`
 
     Argument
     --------
     * `poptbl`: a `ProvPopTable`
+    * `sex`: an object; use only records having the same `sex` in `poptbl`.
     * `age_range`: a list of two ints, `None` by default; only the records
         of `poptbl` having Ages within the closed interval defined by 
         this argument are used. If `None`, then all the Ages are used in
@@ -36,13 +35,16 @@ def plot_pop(
         of a plot
     '''
 
-    pop_age = poptbl.get_pop_groups()[1]
+    pop_groups = poptbl.get_pop_groups()
+    pop_sex = pop_groups[0]
+    pop_age = pop_groups[1]
     pop_end = poptbl.get_pop_end()
     poptbl_pop = poptbl.calculate_pop()
     if age_range is not None:
         poptbl_pop = poptbl_pop\
             .loc[lambda df: df[pop_age] <= age_range[1]]\
             .loc[lambda df: df[pop_age] >= age_range[0]]
+    poptbl_pop = poptbl_pop.loc[lambda df: df[pop_sex] == sex]
     plt.bar(
         poptbl_pop[pop_age].apply(str),
         poptbl_pop[pop_end],
